Documentation
¶
Index ¶
- func AddCommand(root *cobra.Command, cmd *cobra.Command)
- func ExecuteContext(rootCmd *cobra.Command) error
- func NewRootCmd(deps Dependencies) *cobra.Command
- func RunMainMenu() (string, error)
- func WithPanicRecovery(fn func(*cobra.Command, []string) error) func(*cobra.Command, []string) error
- type Dependencies
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddCommand ¶
AddCommand adds a subcommand to the root command with panic recovery
func ExecuteContext ¶
ExecuteContext executes the root command with context
func NewRootCmd ¶
func NewRootCmd(deps Dependencies) *cobra.Command
NewRootCmd creates the root command with dependency injection This follows the Command Factory pattern, avoiding global state
func RunMainMenu ¶
RunMainMenu shows the interactive main menu and returns the selected command name
Types ¶
Click to show internal directories.
Click to hide internal directories.